*======================PROGRAM: PQI_ALL_FORMATS.SAS =======================;

* Title:
*     Format Library for Prevention Quality Indicators Program;
*
* Description:
*     FORMAT LIB FOR AHRQ PREVENTION QUALITY INDICATORS;
*
*           >>> AHRQ QI ICD-09 VERSION 6.0.2 <<<
*              >>> VERSION DATE JULY 2017 <<<
*==========================================================================;
* See the PQI_ICD09_v6_Release_Notes.txt file for version change details.

*PATHNAME specifies the location of the PQI folder which includes the
          Programs, Macros, and SASdata subfolders;
                 
filename CONTROL "c:\Pathname\PQI\Programs\PQI_ALL_CONTROL.SAS"; *<==USER MUST modify; 
%include CONTROL; 

/* -------------------------------------------------------------- */
/* --- FORMATS FOR COUNTY POVERTY DECILES ----------------------- */
/* -------------------------------------------------------------- */
 * County Poverty Deciles based on 2013 Census data.;  
 * Filename may be modified in PQI_ALL_CONTROL.sas.;
%include POVCAT;

proc format library=library;

/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */

/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female';
 
/* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value AGECAT
0 = '00 to 17'
1 = '18 to 39'
2 = '40 to 64'
3 = '65 to 74'
4 = '75+';
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other';
 
/* --- FORMAT FOR CONDITION SPECIFIC AGE CATEGORY ---------------- */
value AGECCAT
0 = '00 to 17'
1 = '18 to 44'
2 = '45 to 64'
3 = '65 to 74'
4 = '75+';
 
* --------------------------------------------------------------
* --- QI DEFINING FORMATS --------------------------------------
* --------------------------------------------------------------

* --- FORMATS - AREA LEVEL PQI INDICATORS ----------------------
* --------------------------------------------------------------;
/* ---------------------------------------------- */
/* Diabetes short term complication rate (ACDIAS) */
/*   PQI 01                                       */
/* ---------------------------------------------- */
/* Diabetes with Short Term Complications */
/* ICD-9-CM Diagnosis Codes: */
value $ACDIASD
'25010' = 1  /* DM KETO T2, DM CONT */
'25011' = 1  /* DM KETO T1, DM CONT */
'25012' = 1  /* DM KETO T2, DM UNCONT */
'25013' = 1  /* DM KETO T1, DM UNCONT */
'25020' = 1  /* DM W/ HYPROSM T2, DM CONT */
'25021' = 1  /* DM W/ HYPROSM T1, DM CONT */
'25022' = 1  /* DM W/ HYPROSM T2, DM UNCNT */
'25023' = 1  /* DM W/ HYPROSM T1, DM UNCNT */
'25030' = 1  /* DM COMA NEC TYP II, DM CNT */
'25031' = 1  /* DM COMA NEC T1, DM CONT */
'25032' = 1  /* DM COMA NEC T2, DM UNCONT */
'25033' = 1  /* DM COMA NEC T1, DM UNCONT */
other   = 0;
/* Gastroenteritis */
/* ICD-9-CM Diagnosis Codes: */
value $ACPGASD
'00861' = "1"  /* INTES INFEC ROTAVIRUS */
'00862' = "1"  /* INTES INFEC ADENOVIRUS */
'00863' = "1"  /* INT INF NORWALK VIRUS */
'00864' = "1"  /* INT INF OTH SML RND VRUS */
'00865' = "1"  /* INTES INFEC CALCIVIRUS */
'00866' = "1"  /* INTES INFEC ASTROVIRUS */
'00867' = "1"  /* INT INF ENTEROVIRUS NEC */
'00869' = "1"  /* ENTERITIS NOS  */
'0088 ' = "1"  /* VIRAL ENTERITIS NOS */
'0090 ' = "1"  /* INFECTIOUS ENTERITIS NOS */
'0091 ' = "1"  /* ENTERITIS OF INFECT ORIG */
'0092 ' = "1"  /* INFECTIOUS DIARRHEA NOS */
'0093 ' = "1"  /* DIARRHEA OF INFECT ORIG */
'5589 ' = "1"  /* NONINF GASTROENTERIT NEC */
other   = "0";
/* --------------------------------- */
/* Perforated Appendix rate (ACSAPP) */
/*   PQI 02                          */
/* --------------------------------- */
/* Perforated Appendix (Outcome of Interest) */
/* ICD-9-CM Diagnosis Codes: */
value $ACSAPPD
'5400 ' = 1  /* AC APPEND W PERITONITIS */
'5401 ' = 1  /* ABSCESS OF APPENDIX */
other   = 0;
/* Appendicitis (Population at Risk) */
/* ICD-9-CM Diagnosis Codes: */
value $ACSAP2D
'5400 ' = 1  /* AC APPEND W PERITONITIS */
'5401 ' = 1  /* ABSCESS OF APPENDIX */
'5409 ' = 1  /* ACUTE APPENDICITIS NOS */
'541  ' = 1  /* APPENDICITIS NOS */
other   = 0;
/* --------------------------------------------- */
/* Diabetes long term complication rate (ACDIAL) */
/*   PQI 03                                      */
/* --------------------------------------------- */
/* Diabetes with Long Term Complications */
/* ICD-9-CM Diagnosis Codes: */
value $ACDIALD
'25040' = 1  /* DM RENAL COMP T2 CONT */
'25041' = 1  /* DM RENAL COMP T1 CONT */
'25042' = 1  /* DM RENAL COMP T2 UNCNT */
'25043' = 1  /* DM RENAL COMP T1 UNCNT */
'25050' = 1  /* DM EYE COMP T2 CONT */
'25051' = 1  /* DM EYE COMP T1 CONT */
'25052' = 1  /* DM EYE COMP T2 UNCNT */
'25053' = 1  /* DM EYE COMP T1 UNCNT */
'25060' = 1  /* DM NEURO COMP T2 CONT */
'25061' = 1  /* DM NEURO COMP T1 CONT */
'25062' = 1  /* DM NEURO COMP T2 UNCNT */
'25063' = 1  /* DM NEURO COMP T1 UNCNT */
'25070' = 1  /* DM CIRCU DIS T2 CONT */
'25071' = 1  /* DM CIRCU DIS T1 CONT */
'25072' = 1  /* DM CIRCU DIS T2 UNCNT */
'25073' = 1  /* DM CIRCU DIS T1 UNCNT */
'25080' = 1  /* DM W COMP NEC T2 CONT */
'25081' = 1  /* DM W COMP NEC T1 CONT */
'25082' = 1  /* DM W COMP NEC T2 UNCNT */
'25083' = 1  /* DM W COMP NEC T1 UNCNT */
'25090' = 1  /* DM W COMPL NOS T2 CONT */
'25091' = 1  /* DM W COMPL NOS T1 CONT */
'25092' = 1  /* DM W COMPL NOS T2 UNCNT */
'25093' = 1  /* DM W COMPL NOS T1 UNCNT */
other   = 0;
/* --------------------- */
/* Asthma rate (ACSAST)  */
/*   PQI  15 - Adult     */
/* --------------------- */
/* Asthma                    */
/* ICD-9-CM Diagnosis Codes: */
value $ACSASTD
'49300' = 1  /* EXT ASTHMA W/O STAT ASTH */
'49301' = 1  /* EXT ASTHMA W STATUS ASTH */
'49302' = 1  /* EXT ASTHMA W ACUTE EXAC */
'49310' = 1  /* INT ASTHMA W/O STAT ASTH */
'49311' = 1  /* INT ASTHMA W STATUS ASTH */
'49312' = 1  /* INT ASTHMA W ACUTE EXAC */
'49320' = 1  /* CH OB ASTH W/O STAT ASTH */
'49321' = 1  /* CH OB ASTHMA W STAT ASTH */
'49322' = 1  /* CH OBS ASTH W ACUTE EXAC */
'49381' = 1  /* EXERCSE IND BRONCHOSPASM */
'49382' = 1  /* COUGH VARIANT ASTHMA */
'49390' = 1  /* ASTHMA W/O STATUS ASTHM */
'49391' = 1  /* ASTHMA W STATUS ASTHMAT */
'49392' = 1  /* ASTHMA W ACUTE EXACERBTN */
other   = 0;
/* EXCLUDE: CYSTIC FIBROSIS AND ANOMALIES OF RESPIRATORY SYSTEM */
/* ICD-9-CM DIAGNOSIS CODES */
value $RESPAN
'27700' = 1  /* CYSTIC FIBROS W/O ILEUS */
'27701' = 1  /* CYSTIC FIBROS W ILEUS */
'27702' = 1  /* CYSTIC FIBROS W PUL MAN */
'27703' = 1  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = 1  /* CYSTIC FIBROSIS NEC */
'51661' = 1  /* NEUROENDOCRINE CELL HYPERPLASIA OF INFANCY */
'51662' = 1  /* PULMONARY INTERSTITIAL GLYCOGENESIS */
'51663' = 1  /* SURFACTANT MUTATIONS OF THE LUNG*/
'51664' = 1  /* ALVEOLAR CAPILLARY DYSPLASIA WITH VEIN MISALIGNMENT*/
'51669' = 1  /* OTHER INTERSTITIAL LUNG DISEASES OF THE CHILDHOOD */
'74721' = 1  /* ANOMALIES OF AORTIC ARCH */
'7483 ' = 1  /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 1  /* CONGENITAL CYSTIC LUNG */
'7485 ' = 1  /* AGENESIS OF LUNG */
'74860' = 1  /* LUNG ANOMALY NOS */
'74861' = 1  /* CONGEN BRONCHIECTASIS */
'74869' = 1  /* LUNG ANOMALY NEC */
'7488 ' = 1  /* RESPIRATORY ANOMALY NEC */
'7489 ' = 1  /* RESPIRATORY ANOMALY NOS */
'7503 ' = 1  /* CONG ESOPH FISTULA/ATRES */
'7593 ' = 1  /* SITUS INVERSUS */
'7707 ' = 1  /* PERINATAL CHR RESP DIS*/
other   = 0;
/* ------------------ */
/* COPD rate (ACCOPD) */
/*   PQI 05          */
/* ------------------ */
/* COPD (1) */
/* ICD-9-CM Diagnosis Codes: */
value $ACCOPDD
'4910 ' = 1  /* SIMPLE CHR BRONCHITIS */
'4911 ' = 1  /* MUCOPURUL CHR BRONCHITIS */
'49120' = 1  /* OBS CHR BRNC W/O ACT EXA */
'49121' = 1  /* OBS CHR BRNC W ACT EXA */
'49122' = 1  /* OBS CHR BRONC W AC BRONC */
'4918 ' = 1  /* CHRONIC BRONCHITIS NEC */
'4919 ' = 1  /* CHRONIC BRONCHITIS NOS */
'4920 ' = 1  /* EMPHYSEMATOUS BLEB */
'4928 ' = 1  /* EMPHYSEMA NEC */
'494  ' = 1  /* BRONCHIECTASIS */
'4940 ' = 1  /* BRONCHIECTAS W/O AC EXAC */
'4941 ' = 1  /* BRONCHIECTASIS W AC EXAC */
'496  ' = 1  /* CHR AIRWAY OBSTRUCT NEC */
other   = 0;
/* -------------------------- */
/* Hypertension rate (ACSHYP) */
/*   PQI 07                  */
/* -------------------------- */
/* Hypertension */
/* ICD-9-CM Diagnosis Codes: */
value $ACSHYPD
'4010 ' = 1  /* MALIGNANT HYPERTENSION */
'4019 ' = 1  /* HYPERTENSION NOS */
'40200' = 1  /* MAL HYPERTEN HRT DIS NOS */
'40210' = 1  /* BEN HYPERTEN HRT DIS NOS */
'40290' = 1  /* HYPERTENSIVE HRT DIS NOS */
'40300' = 1  /* MAL HYP REN W/O REN FAIL */
'40310' = 1  /* BEN HYP REN W/O REN FAIL */
'40390' = 1  /* HYP REN NOS W/O REN FAIL */
'40400' = 1  /* MAL HY HT/REN W/O CHF/RF */
'40410' = 1  /* BEN HY HT/REN W/O CHF/RF */
'40490' = 1  /* HY HT/REN NOS W/O CHF/RF */
other   = 0;
/* Exclude: Stage I-IV Kidney Disease */
/* ICD-9-CM Diagnosis Codes: */
value $ACSHY2D
'40300' = 1  /* MAL HYP REN W/O REN FAIL */
'40310' = 1  /* BEN HYP REN W/O REN FAIL */
'40390' = 1  /* HYP REN NOS W/O REN FAIL */
'40400' = 1  /* MAL HY HT/REN W/O CHF/RF */
'40410' = 1  /* BEN HY HT/REN W/O CHF/RF */
'40490' = 1  /* HY HT/REN NOS W/O CHF/RF */
other   = 0;
/* EXCLUDE: CHRONIC RENAL FAILURE */
/* ICD-9-CM DIAGNOSIS CODES: */
value $CRENLFD
"40301" = "1" /* MAL HYP KIDNEY W CHR KID */
"40311" = "1" /* BEN HYP KIDNEY W CHR KID */
"40391" = "1" /* HYP KIDNEY NOS W CHR KID */
"40402" = "1" /* MAL HY HRT/KID W CHR KID */
"40403" = "1" /* MAL HYP HRT/KID W HF/KID */
"40412" = "1" /* BEN HYP HT/KID W CHR KID */
"40413" = "1" /* BEN HYP HT/KID W HF/KID  */
"40492" = "1" /* HYP HT/KID NOS W CHR KID */
"40493" = "1" /* HYP HRT/KID NOS W HF/KID */
"5855 " = "1" /* CHRON KIDNEY DIS STAGE V */
"5856 " = "1" /* END STAGE RENAL DISEASE */
other   = "0";
/* Renal Failure */
/* ICD-9-CM Diagnosis Codes: */
value $PHYSIDB
"5845"      = "1" /* AC KIDNY FAIL, TUBR NECR */
"5846"      = "1" /* AC KIDNY FAIL, CORT NECR */
"5847"      = "1" /* AC KIDNY FAIL, MEDU NECR */
"5848"      = "1" /* ACUTE KIDNEY FAILURE NEC */
"5849"      = "1" /* ACUTE KIDNEY FAILURE NOS */
"586"   = "1" /* RENAL FAILURE NOS */
"9975"  = "1" /* SURG COMPL-URINARY TRACT */
other   = "0";
/* ICD-9-CM Procedure codes: */
value $ACSHYPP
'3895' = 1  /* VEN CATH RENAL DIALYSIS */
'3927' = 1  /* DIALYSIS ARTERIOVENOSTOM */
'3929' = 1  /* VASC SHUNT & BYPASS NEC */
'3942' = 1  /* REVIS REN DIALYSIS SHUNT */
'3943' = 1  /* REMOV REN DIALYSIS SHUNT */
'3993' = 1  /* INSERT VES-TO-VES CANNUL */
'3994' = 1  /* REPLAC VES-TO-VES CANNUL */
other   = 0;
/* Exclude: Cardiac Procedures */
/* ICD-9-CM Procedure codes: */
value $ACSCARP
'0050' = 1  /* IMPL CRT PACEMAKER SYS */
'0051' = 1  /* IMPL CRT DEFIBRILLAT SYS */
'0052' = 1  /* IMP/REP LEAD LF VEN SYS */
'0053' = 1  /* IMP/REP CRT PACEMAKR GEN */
'0054' = 1  /* IMP/REP CRT DEFIB GENAT */
'0056' = 1  /* INS/REP IMPL SENSOR LEAD */
'0057' = 1  /* IMP/REP SUBCUE CARD DEV */
'0066' = 1  /* PTCA                    */
'1751' = 1  /* Implant CCM,total system */
'1752' = 1  /* Implant CCM pulse genrtr */
'1755' = 1  /* TRANSLUMINAL CORONARY ATHERECTOMY */
'3500' = 1  /* CLOSED VALVOTOMY NOS */
'3501' = 1  /* CLOSED AORTIC VALVOTOMY */
'3502' = 1  /* CLOSED MITRAL VALVOTOMY */
'3503' = 1  /* CLOSED PULMON VALVOTOMY */
'3504' = 1  /* CLOSED TRICUSP VALVOTOMY */
'3505' = 1  /* ENDOVASCULAR REPLACEMENT OF AORTIC VALVE */
'3506' = 1  /* TRANSAPICAL REPLACEMENT OF AORTIC VALVE */
'3507' = 1  /* ENDOVASCULAR REPLACEMENT OF PULMONARY VALVE */
'3508' = 1  /* TRANSAPICAL REPLACEMENT OF PULMONARY VALVE  */
'3509' = 1  /* ENDOVASCULAR REPLACEMENT OF UNSPECIFIED HEART VALVE */
'3510' = 1  /* OPEN VALVULOPLASTY NOS */
'3511' = 1  /* OPN AORTIC VALVULOPLASTY */
'3512' = 1  /* OPN MITRAL VALVULOPLASTY */
'3513' = 1  /* OPN PULMON VALVULOPLASTY */
'3514' = 1  /* OPN TRICUS VALVULOPLASTY */
'3520' = 1  /* REPLACE HEART VALVE NOS */
'3521' = 1  /* REPLACE AORT VALV-TISSUE */
'3522' = 1  /* REPLACE AORTIC VALVE NEC */
'3523' = 1  /* REPLACE MITR VALV-TISSUE */
'3524' = 1  /* REPLACE MITRAL VALVE NEC */
'3525' = 1  /* REPLACE PULM VALV-TISSUE */
'3526' = 1  /* REPLACE PULMON VALVE NEC */
'3527' = 1  /* REPLACE TRIC VALV-TISSUE */
'3528' = 1  /* REPLACE TRICUSP VALV NEC */
'3531' = 1  /* PAPILLARY MUSCLE OPS */
'3532' = 1  /* CHORDAE TENDINEAE OPS */
'3533' = 1  /* ANNULOPLASTY */
'3534' = 1  /* INFUNDIBULECTOMY */
'3535' = 1  /* TRABECUL CARNEAE CORD OP */
'3539' = 1  /* TISS ADJ TO VALV OPS NEC */
'3541' = 1  /* ENLARGE EXISTING SEP DEF */
'3542' = 1  /* CREATE SEPTAL DEFECT */
'3550' = 1  /* PROSTH REP HRT SEPTA NOS */
'3551' = 1  /* PROS REP ATRIAL DEF-OPN */
'3552' = 1  /* PROS REPAIR ATRIA DEF-CL */
'3553' = 1  /* PROST REPAIR VENTRIC DEF */
'3554' = 1  /* PROS REP ENDOCAR CUSHION */
'3555' = 1  /* PROS REP VENTRC DEF-CLOS */
'3560' = 1  /* GRFT REPAIR HRT SEPT NOS */
'3561' = 1  /* GRAFT REPAIR ATRIAL DEF */
'3562' = 1  /* GRAFT REPAIR VENTRIC DEF */
'3563' = 1  /* GRFT REP ENDOCAR CUSHION */
'3570' = 1  /* HEART SEPTA REPAIR NOS */
'3571' = 1  /* ATRIA SEPTA DEF REP NEC */
'3572' = 1  /* VENTR SEPTA DEF REP NEC */
'3573' = 1  /* ENDOCAR CUSHION REP NEC */
'3581' = 1  /* TOT REPAIR TETRAL FALLOT */
'3582' = 1  /* TOTAL REPAIR OF TAPVC */
'3583' = 1  /* TOT REP TRUNCUS ARTERIOS */
'3584' = 1  /* TOT COR TRANSPOS GRT VES */
'3591' = 1  /* INTERAT VEN RETRN TRANSP */
'3592' = 1  /* CONDUIT RT VENT-PUL ART */
'3593' = 1  /* CONDUIT LEFT VENTR-AORTA */
'3594' = 1  /* CONDUIT ARTIUM-PULM ART */
'3595' = 1  /* HEART REPAIR REVISION */
'3596' = 1  /* PERC HEART VALVULOPLASTY */
'3597' = 1  /* PERC MTRL VLV REPR W IMP */   
'3598' = 1  /* OTHER HEART SEPTA OPS */
'3599' = 1  /* OTHER HEART VALVE OPS */
'3601' = 1  /* PTCA-1 VESSEL W/O AGENT */
'3602' = 1  /* PTCA-1 VESSEL WITH AGNT */
'3603' = 1  /* OPEN CORONRY ANGIOPLASTY */
'3604' = 1  /* INTRCORONRY THROMB INFUS */
'3605' = 1  /* PTCA-MULTIPLE VESSEL */
'3606' = 1  /* INSERT OF COR ART STENT */
'3607' = 1  /* INS DRUG-ELUT CORONRY ST */
'3609' = 1  /* REM OF COR ART OBSTR NEC */
'3610' = 1  /* AORTOCORONARY BYPASS NOS */
'3611' = 1  /* AORTOCOR BYPAS-1 COR ART */
'3612' = 1  /* AORTOCOR BYPAS-2 COR ART */
'3613' = 1  /* AORTOCOR BYPAS-3 COR ART */
'3614' = 1  /* AORTCOR BYPAS-4+ COR ART */
'3615' = 1  /* 1 INT MAM-COR ART BYPASS */
'3616' = 1  /* 2 INT MAM-COR ART BYPASS */
'3617' = 1  /* ABD-CORON ART BYPASS */
'3619' = 1  /* HRT REVAS BYPS ANAS NEC */
'362 ' = 1  /* ARTERIAL IMPLANT REVASC */
'363 ' = 1  /* OTH HEART REVASCULAR */
'3631' = 1  /* OPEN CHEST TRANS REVASC */
'3632' = 1  /* OTH TRANSMYO REVASCULAR */
'3633' = 1  /* ENDO TRANSMYO REVASCULAR */
'3634' = 1  /* PERC TRANSMYO REVASCULAR */
'3639' = 1  /* OTH HEART REVASCULAR */
'3691' = 1  /* CORON VESS ANEURYSM REP */
'3699' = 1  /* HEART VESSEL OP NEC */
'3731' = 1  /* PERICARDIECTOMY */
'3732' = 1  /* HEART ANEURYSM EXCISION */
'3733' = 1  /* EXC/DEST HRT LESION OPEN */
'3734' = 1  /* EXC/DEST HRT LES OTHER */
'3735' = 1  /* PARTIAL VENTRICULECTOMY */
'3736' = 1  /* EXC LEFT ATRIAL APPENDAG */
'3737' = 1  /* EXC/DEST HRT LES, THRSPC */    
'3741' = 1  /* IMPLANTATION            */
'375 ' = 1  /* HEART TRANSPLANTATION */
'3751' = 1  /* HEART TRANSPLANTATION */
'3752' = 1  /* IMPLANT TOT REP HRT SYS */
'3753' = 1  /* REPL/REP THORAC UNIT HRT */
'3754' = 1  /* REPL/REP OTH TOT HRT SYS */
'3755' = 1  /* REM INT BIVENT HRT SYS */
'3760' = 1  /* IMP BIVN EXT HRT AST SYS */
'3761' = 1  /* PULSATION BALLOON IMPLAN */
'3762' = 1  /* INSRT NON-IMPL CIRC DEV */
'3763' = 1  /* REPAIR HEART ASSIST SYS */
'3764' = 1  /* REMVE EXT HRT ASSIST SYS */
'3765' = 1  /* IMP VENT EXT HRT AST SYS */
'3766' = 1  /* IMPLANTABLE HRT ASSIST */
'3770' = 1  /* INT INSERT PACEMAK LEAD */
'3771' = 1  /* INT INSERT LEAD IN VENT */
'3772' = 1  /* INT INSER LEAD ATRI-VENT */
'3773' = 1  /* INT INSER LEAD IN ATRIUM */
'3774' = 1  /* INT OR REPL LEAD EPICAR */
'3775' = 1  /* REVISION OF LEAD */
'3776' = 1  /* REPL TV ATRI-VENT LEAD */
'3777' = 1  /* REMOVAL OF LEAD W/O REPL */
'3778' = 1  /* INSER TEMP PACEMAKER SYS */
'3779' = 1  /* REVIS OR RELOCATE POCKET */
'3780' = 1  /* INT OR REPL PERM PACEMKR */
'3781' = 1  /* INT INSERT 1-CHAM, NON */
'3782' = 1  /* INT INSERT 1-CHAM, RATE */
'3783' = 1  /* INT INSERT DUAL-CHAM DEV */
'3785' = 1  /* REPL PACEM W 1-CHAM, NON */
'3786' = 1  /* REPL PACEM 1-CHAM, RATE */
'3787' = 1  /* REPL PACEM W DUAL-CHAM */
'3789' = 1  /* REVISE OR REMOVE PACEMAK */
'3794' = 1  /* IMPLT/REPL CARDDEFIB TOT */
'3795' = 1  /* IMPLT CARDIODEFIB LEADS */
'3796' = 1  /* IMPLT CARDIODEFIB GENATR */
'3797' = 1  /* REPL CARDIODEFIB LEADS */
'3798' = 1  /* REPL CARDIODEFIB GENRATR */
'3826' = 1  /* INSERTION OF IMPLNATABLE PRESSOR SENSOR WITHOUT LEAD FOR INTRACARDIAC OR GREAT VESSEL HEMO DYNAMIC MONITORING */
other   = 0;
/* -------------------------------------- */
/* Congestive Heart Failure rate (MRTCHF) */
/* Mortality Indicator (from IQI  16)     */
/* -------------------------------------- */
/* CHF */
/* PQI 08*/
/* ICD-9-CM Diagnosis Codes: */
value $MRTCHFD
'39891' = '1'  /* RHEUMATIC HEART FAILURE */
'40201' = '1'  /* MAL HYPERT HRT DIS W CHF */
'40211' = '1'  /* BENIGN HYP HRT DIS W CHF */
'40291' = '1'  /* HYPERTEN HEART DIS W CHF */
'40401' = '1'  /* MAL HYPER HRT/REN W CHF */
'40403' = '1'  /* MAL HYP HRT/REN W CHF&RF */
'40411' = '1'  /* BEN HYPER HRT/REN W CHF */
'40413' = '1'  /* BEN HYP HRT/REN W CHF&RF */
'40491' = '1'  /* HYPER HRT/REN NOS W CHF */
'40493' = '1'  /* HYP HT/REN NOS W CHF&RF */
'4280 ' = '1'  /* CONGESTIVE HEART FAILURE */
'4281 ' = '1'  /* LEFT HEART FAILURE */
'42820' = '1'  /* SYSTOLIC HRT FAILURE NOS */
'42821' = '1'  /* AC SYSTOLIC HRT FAILURE */
'42822' = '1'  /* CHR SYSTOLIC HRT FAILURE */
'42823' = '1'  /* AC ON CHR SYST HRT FAIL */
'42830' = '1'  /* DIASTOLC HRT FAILURE NOS */
'42831' = '1'  /* AC DIASTOLIC HRT FAILURE */
'42832' = '1'  /* CHR DIASTOLIC HRT FAIL */
'42833' = '1'  /* AC ON CHR DIAST HRT FAIL */
'42840' = '1'  /* SYST/DIAST HRT FAIL NOS */
'42841' = '1'  /* AC SYST/DIASTOL HRT FAIL */
'42842' = '1'  /* CHR SYST/DIASTL HRT FAIL */
'42843' = '1'  /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = '1'  /* HEART FAILURE NOS */
other   = '0';
/* ------------------------- */
/* Dehydration rate (ACSDEH) */
/*   PQI  10                 */
/* ------------------------- */
/* Dehydration */
/* ICD-9-CM Diagnosis Codes: */
value $ACSDEHD
'2765 ' = 1  /* HYPOVOLEMIA */
'27650' = 1  /* VOLUME DEPLETION */
'27651' = 1  /* DEHYDRATION */
'27652' = 1  /* HYPOVOLEMIA */
other   = 0;
/* --------------------------------- */
/* Bacterial Pneumonia rate (ACSBAC) */
/*   PQI  11                         */
/* --------------------------------- */
/* Bacterial Pneumonia */
/* ICD-9-CM Diagnosis Codes: */
value $ACSBACD
'481  ' = 1  /* PNEUMOCOCCAL PNEUMONIA */
'4822 ' = 1  /* H.INFLUENZAE PNEUMONIA */
'48230' = 1  /* STREP PNEUMONIA UNSPEC */
'48231' = 1  /* GRP A STREP PNEUMONIA */
'48232' = 1  /* GRP B STREP PNEUMONIA */
'48239' = 1  /* OTH STREP PNEUMONIA */
'48241' = 1 /* METH SUS PNEUM D/T STAPH */
'48242' = 1 /* METH RES PNEU D/T STAPH */
'4829 ' = 1  /* BACTERIAL PNEUMONIA NOS */
'4830 ' = 1  /* MYCOPLASMA PNEUMONIA */
'4831 ' = 1  /* CHLAMYDIA PNEUMONIA */
'4838 ' = 1  /* OTH SPEC ORG PNEUMONIA */
'485  ' = 1  /* BRONCOPNEUMONIA ORG NOS */
'486  ' = 1  /* PNEUMONIA, ORGANISM NOS */
'48240' = 1  /* Added 12-01-2015 */
'48249' = 1  /* Added 12-01-2015 */
other   = 0;
/* Exclude: Sickle Cell      */
/* ICD-9-CM Diagnosis Codes: */
value $ACSBA2D
'28241' = 1  /* THLASEMA HB-S W/O CRISIS */
'28242' = 1  /* THLASSEMIA HB-S W CRISIS */
'28260' = 1  /* SICKLE-CELL ANEMIA NOS */
'28261' = 1  /* HB-S DISEASE W/O CRISIS */
'28262' = 1  /* HB-S DISEASE WITH CRISIS */
'28263' = 1  /* SICKLE-CELL/HB-C DISEASE */
'28264' = 1  /* HB-S/HB-C DIS W CRISIS */
'28268' = 1  /* HB-S DIS W/O CRISIS NEC */
'28269' = 1  /* SICKLE-CELL ANEMIA NEC */
other   = 0;
/* HYPEROSMOLALITY AND /OR HYPERNATREMIA   */
/* ICD-09-CM DIAGNOSIS CODES:              */
value $HYPERID
'2760 ' = 1  /* HYPEROSMOLALITY */
other   = 0;
/* ------------------------------- */
/* Urinary Infection rate (ACSUTI) */
/*   PQI  12                       */
/* ------------------------------- */
/* Urinary Infection */
/* ICD-9-CM Diagnosis Codes: */
value $ACSUTID
'59010' = 1  /* AC PYELONEPHRITIS NOS */
'59011' = 1  /* AC PYELONEPHR W MED NECR */
'5902 ' = 1  /* RENAL/PERIRENAL ABSCESS */
'5903 ' = 1  /* PYELOURETERITIS CYSTICA */
'59080' = 1  /* PYELONEPHRITIS NOS */
'59081' = 1  /* PYELONEPHRIT IN OTH DIS */
'5909 ' = 1  /* INFECTION OF KIDNEY NOS */
'5950 ' = 1  /* ACUTE CYSTITIS */
'5959 ' = 1  /* CYSTITIS NOS */
'5990 ' = 1  /* URIN TRACT INFECTION NOS */
other   = 0;
/* EXCLUDE: IMMUNOCOMPROMISED */
/* ICD-9-CM DIAGNOSIS CODES   */
value $IMMUNID
"042"   = "1" /* HUMAN IMMUNODEFICIENCY VIRUS DISEASE */
"1363"  = "1" /* PNEUMOCYSTOSIS */
"1992"  = "1" /* MALIG NEOPL-TRANSP ORGAN */
"23873" = "1" /* HI GRDE MYELODYS SYN LES */
"23876" = "1" /* MYELOFI W MYELO METAPLAS */
"23877" = "1" /* POST TP LYMPHPROLIF DIS */
"23879" = "1" /* LYMPH/HEMATPOITC TIS NEC */
"260  " = "1" /* KWASHIORKOR */
"261  " = "1" /* NUTRITIONAL MARASMUS */
"262  " = "1" /* OTH SEVERE MALNUTRITION */
"27900" = "1" /* HYPOGAMMAGLOBULINEM NOS */
"27901" = "1" /* SELECTIVE IGA IMMUNODEF */
"27902" = "1" /* SELECTIVE IGM IMMUNODEF */
"27903" = "1" /* SELECTIVE IG DEFIC NEC */
"27904" = "1" /* CONG HYPOGAMMAGLOBULINEM */
"27905" = "1" /* IMMUNODEFIC W HYPER-IGM */
"27906" = "1" /* COMMON VARIABL IMMUNODEF */
"27909" = "1" /* HUMORAL IMMUNITY DEF NEC */
"27910" = "1" /* IMMUNDEF T-CELL DEF NOS */
"27911" = "1" /* DIGEORGES SYNDROME */
"27912" = "1" /* WISKOTT-ALDRICH SYNDROME */
"27913" = "1" /* NEZELOFS SYNDROME */
"27919" = "1" /* DEFIC CELL IMMUNITY NOS */
"2792"  = "1" /* COMBINED IMMUNITY DEFICIENCY */
"2793"  = "1" /* UNSPECIFIED IMMUNITY DEFICIENCY */
"2794"  = "1" /* AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED */
"27941"	= "1" /* Autoimmun lymphprof synd */
"27949"	= "1" /* Autoimmune disease NEC */
"27950" = "1" /* GRAFT-VERSUS-HOST NOS */
"27951" = "1" /* AC GRAFT-VERSUS-HOST DIS */
"27952" = "1" /* CHRONC GRAFT-VS-HOST DIS */
"27953" = "1" /* AC ON CHRN GRFT-VS-HOST */
"2798"  = "1" /* OTHER SPECIFIED DISORDERS INVOLVING THE IMMUNE MECHANISM */
"2799"  = "1" /* UNSPECIFIED DISORDER OF IMMUNE MECHANISM */
"28409" = "1" /* CONST APLASTC ANEMIA NEC */
"2841 " = "1" /* PANCYTOPENIA */
"28411 " = "1" /* ANTINEOPLASTIC CHEMOTHERAPY INDUCED PANCYTOPENIA */
"28412 " = "1" /* OTHER DRUG INDUCED PANCYTOPENIA */
"28419 " = "1" /* OTHER PANCYTOPENIA */
"2880 " = "1" /* AGRANULOCYTOSIS */
"28800" = "1" /* NEUTROPENIA NOS */
"28801" = "1" /* CONGENITAL NEUTROPENIA */
"28802" = "1" /* CYCLIC NEUTROPENIA */
"28803" = "1" /* DRUG INDUCED NEUTROPENIA */
"28809" = "1" /* NEUTROPENIA NEC */
"2881 " = "1" /* FUNCTION DIS NEUTROPHILS */
"2882 " = "1" /* GENETIC ANOMALY LEUKOCYT */
"2884 " = "1" /* HEMOPHAGOCYTIC SYNDROMES */
"28850" = "1" /* LEUKOCYTOPENIA NOS */
"28851" = "1" /* LYMPHOCYTOPENIA */
"28859" = "1" /* DECREASED WBC COUNT NEC */
"28953" = "1" /* NEUTROPENIC SPLENOMEGALY */
"28983" = "1" /* MYELOFIBROSIS */
"40301" = "1" /* MAL HYP KIDNEY W CHR KID */
"40311" = "1" /* BEN HYP KIDNEY W CHR KID */
"40391" = "1" /* HYP KIDNEY NOS W CHR KID */
"40402" = "1" /* MAL HY HRT/KID W CHR KID */
"40403" = "1" /* MAL HYP HRT/KID W HF/KID */
"40412" = "1" /* BEN HYP HT/KID W CHR KID */
"40413" = "1" /* BEN HYP HT/KID W HF/KID */
"40492" = "1" /* HYP HT/KID NOS W CHR KID */
"40493" = "1" /* HYP HRT/KID NOS W HF/KID */
"5793 " = "1" /* INTEST POSTOP NONABSORB */
"585  " = "1" /* CHRONIC RENAL FAILURE */
"5855 " = "1" /* CHRON KIDNEY DIS STAGE V */
"5856 " = "1" /* END STAGE RENAL DISEASE */
"9968"  = "1" /* COMPLICATIONS OF TRANSPLANTED ORGAN */
"99680" = "1" /* COMP ORGAN TRANSPLNT NOS */
"99681" = "1" /* COMPL KIDNEY TRANSPLANT */
"99682" = "1" /* COMPL LIVER TRANSPLANT */
"99683" = "1" /* COMPL HEART TRANSPLANT */
"99684" = "1" /* COMPL LUNG TRANSPLANT */
"99685" = "1" /* COMPL MARROW TRANSPLANT */
"99686" = "1" /* COMPL PANCREAS TRANSPLNT */
"99687" = "1" /* COMP INTESTINE TRANSPLNT */
"99688" = "1" /* STEM CELL TRANSPLANT COMPLICATIONS */
"99689" = "1" /* COMP OTH ORGAN TRANSPLNT */
"V420"  = "1" /* KIDNEY REPLACED BY TRANSPLANT */
"V421"  = "1" /* HEART REPLACED BY TRANSPLANT */
"V426"  = "1" /* LUNG REPLACED BY TRANSPLANT */
"V427"  = "1" /* LIVER REPLACED BY TRANSPLANT */
"V428"  = "1" /* OTHER SPECIFIED ORGAN OR TISSUE */
"V4281" = "1" /* BONE MARROW SPECIFIED BY TRANSPLANT */
"V4282" = "1" /* PERIPHERAL STEM CELLS REPLACED BY TRANSPLANT */
"V4283" = "1" /* PANCREAS REPLACED BY TRANSPLANT */
"V4284" = "1" /* INTESTINES REPLACE BY TRANSPLANT */
"V4289" = "1" /* OTHER REPLACED BY TRANSPLANT */
"V451 " = "1" /* RENAL DIALYSIS STATUS */
"V4511" = "1" /* RENAL DIALYSIS STATUS */
"V560 " = "1" /* RENAL DIALYSIS ENCOUNTER */
"V561 " = "1" /* FT/ADJ XTRCORP DIAL CATH */
"V562 " = "1" /* FIT/ADJ PERIT DIAL CATH */
other   = "0";
/* EXCLUDE: IMMUNOCOMPROMISED */
/* ICD-9-CM PROCEDURE CODES   */
value $IMMUNIP
"0018" = "1" /* INFUS IMMUNOSUP ANTIBODY */
"335"  = "1" /* LUNG TRANSPLANT */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"375"  = "1" /* HEART TRANSPLANTATION */
"3751" = "1" /* HEART TRANSPLANTATION */
"410"  = "1" /* OPERATIONS ON BONE MAROW AND SPLEEN */
"4100" = "1" /* BONE MARROW TRNSPLNT NOS */
"4101" = "1" /* AUTO BONE MT W/O PURG */
"4102" = "1" /* ALO BONE MARROW TRNSPLNT */
"4103" = "1" /* ALLOGRFT BONE MARROW NOS */
"4104" = "1" /* AUTO HEM STEM CT W/O PUR */
"4105" = "1" /* ALLO HEM STEM CT W/O PUR */
"4106" = "1" /* CORD BLD STEM CELL TRANS */
"4107" = "1" /* AUTO HEM STEM CT W PURG */
"4108" = "1" /* ALLO HEM STEM CT W PURG */
"4109" = "1" /* AUTO BONE MT W PURGING */
"4697" = "1" /* TRANSPLANT OF INTESTINE ADDED IN V6*/ 
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5282" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5285" = "1" /* ALLOTRANSPLANTATION OF CELLS OF ISLETS OF LNGERHANS */
"5286" = "1" /* TRANSPLANTATION OF CELLS OF ISLETS OF LANGERHANS, NOS */
"5569" = "1" /* OTHER KIDNEY TRANSPLANTATION */
other  = "0";
/* EXCLUDE: KIDNEY OR URINARY TRACT DISORDER */
/* ICD-9-CM DIAGNOSIS CODES */
value $KIDNEY
'59000' = 1  /* CHR PYELONEPHRITIS NOS */
'59001' = 1  /* CHR PYELONEPH W MED NECR */
'59370' = 1  /* VESCOURETRL RFLUX UNSPCF */
'59371' = 1  /* VESICOURETERAL REFLUX UNILTRL */
'59372' = 1  /* VESICOURETERAL REFLUX NPHT BLTRL */
'59373' = 1  /* VESICOURETERAL REFLUX W NPHT NOS */
'7530 ' = 1  /*  RENAL AGENESIS */
'75310' = 1  /* CYSTIC KIDNEY DISEAS NOS */
'75311' = 1  /* CONGENITAL RENAL CYST */
'75312' = 1  /* POLYCYSTIC KIDNEY NOS */
'75313' = 1  /* POLYCYST KID-AUTOSOM DOM */
'75314' = 1  /* POLYCYST KID-AUTOSOM REC */
'75315' = 1  /* RENAL DYSPLASIA */
'75316' = 1  /* MEDULLARY CYSTIC KIDNEY */
'75317' = 1  /* MEDULLARY SPONGE KIDNEY */
'75319' = 1  /* CYSTIC KIDNEY DISEAS NEC */
'75320' = 1  /* OBS DFCT REN PLV&URT NOS */
'75321' = 1  /* CONGEN OBST URTROPLV JNC */
'75322' = 1  /* CONG OBST URETEROVES JNC */
'75323' = 1  /* CONGENITAL URETEROCELE */
'75329' = 1  /* OBST DEF REN PLV&URT NEC */
'7533 ' = 1  /*  KIDNEY ANOMALY NEC */
'7534 ' = 1  /*  URETERAL ANOMALY NEC */
'7535 ' = 1  /*  EXSTROPHY OF URNIARY BLADDER */
'7536 ' = 1  /*  ATRESIA AND STENOSIS OF URETHRA AND BLADDER NECK */
'7538 ' = 1  /*  CYSTOURETHRAL ANOM NEC */
'7539 ' = 1  /*  URINARY ANOMALY NOS */
other   = 0;
/* ------------------------------------ */
/* Exclude: Cardiac procedures */
/* ICD-9-CM Procedure Codes:   */
/* See PQI  07 Hypertension    */
/* ----------------------------------- */
/* Diabetes uncontrolled rate (ACDIAU) */
/*   PQI  14                           */
/* ----------------------------------- */
/* Diabetes uncontrolled     */
/* ICD-9-CM Diagnosis Codes: */
value $ACDIAUD
'25002' = 1  /* DMII WO CMP UNCNTRLD */
'25003' = 1  /* DMI WO CMP UNCNTRLD */
other   = 0;
/* ----------------------------------------- */
/* Lower extremity amputation rate (ACSCLEA) */
/*   PQI  16                                 */
/* ----------------------------------------- */
/* Lower extremity amputation */
/* ICD-9-CM Procedure Codes: */
value $ACSLEAP
'8410' = 1  /* LOWER LIMB AMPUTAT NOS */
'8412' = 1  /* AMPUTATION THROUGH FOOT */
'8413' = 1  /* DISARTICULATION OF ANKLE */
'8414' = 1  /* AMPUTAT THROUGH MALLEOLI */
'8415' = 1  /* BELOW KNEE AMPUTAT NEC */
'8416' = 1  /* DISARTICULATION OF KNEE */
'8417' = 1  /* ABOVE KNEE AMPUTATION */
'8418' = 1  /* DISARTICULATION OF HIP */
'8419' = 1  /* HINDQUARTER AMPUTATION */
other   = 0;
/* Include only: Diabetes */
/* ICD-9-CM Diagnosis Codes: */
value $ACSLEAD
'25000' = 1  /* DMII WO CMP NT ST UNCNTR */
'25001' = 1  /* DMI WO CMP NT ST UNCNTRL */
'25002' = 1  /* DMII WO CMP UNCNTRLD */
'25003' = 1  /* DMI WO CMP UNCNTRLD */
'25010' = 1  /* DMII KETO NT ST UNCNTRLD */
'25011' = 1  /* DMI KETO NT ST UNCNTRLD */
'25012' = 1  /* DMII KETOACD UNCONTROLD */
'25013' = 1  /* DMI KETOACD UNCONTROLD */
'25020' = 1  /* DMII HPRSM NT ST UNCNTRL */
'25021' = 1  /* DMI HPRSM NT ST UNCNTRLD */
'25022' = 1  /* DMII HPROSMLR UNCONTROLD */
'25023' = 1  /* DMI HPROSMLR UNCONTROLD */
'25030' = 1  /* DMII O CM NT ST UNCNTRLD */
'25031' = 1  /* DMI O CM NT ST UNCNTRLD */
'25032' = 1  /* DMII OTH COMA UNCONTROLD */
'25033' = 1  /* DMI OTH COMA UNCONTROLD */
'25040' = 1  /* DMII RENL NT ST UNCNTRLD */
'25041' = 1  /* DMI RENL NT ST UNCNTRLD */
'25042' = 1  /* DMII RENAL UNCNTRLD */
'25043' = 1  /* DMI RENAL UNCNTRLD */
'25050' = 1  /* DMII OPHTH NT ST UNCNTRL */
'25051' = 1  /* DMI OPHTH NT ST UNCNTRLD */
'25052' = 1  /* DMII OPHTH UNCNTRLD */
'25053' = 1  /* DMI OPHTH UNCNTRLD */
'25060' = 1  /* DMII NEURO NT ST UNCNTRL */
'25061' = 1  /* DMI NEURO NT ST UNCNTRLD */
'25062' = 1  /* DMII NEURO UNCNTRLD */
'25063' = 1  /* DMI NEURO UNCNTRLD */
'25070' = 1  /* DMII CIRC NT ST UNCNTRLD */
'25071' = 1  /* DMI CIRC NT ST UNCNTRLD */
'25072' = 1  /* DMII CIRC UNCNTRLD */
'25073' = 1  /* DMI CIRC UNCNTRLD */
'25080' = 1  /* DMII OTH NT ST UNCNTRLD */
'25081' = 1  /* DMI OTH NT ST UNCNTRLD */
'25082' = 1  /* DMII OTH UNCNTRLD */
'25083' = 1  /* DMI OTH UNCNTRLD */
'25090' = 1  /* DMII UNSPF NT ST UNCNTRL */
'25091' = 1  /* DMI UNSPF NT ST UNCNTRLD */
'25092' = 1  /* DMII UNSPF UNCNTRLD */
'25093' = 1  /* DMI UNSPF UNCNTRLD */
other   = 0;
/* Exclude: Trauma */
/* ICD-9-CM Diagnosis Codes: */
value $ACLEA2D
'8950 ' = 1  /* AMPUTATION TOE */
'8951 ' = 1  /* AMPUTATION TOE-COMPLICAT */
'8960 ' = 1  /* AMPUTATION FOOT, UNILAT */
'8961 ' = 1  /* AMPUT FOOT, UNILAT-COMPL */
'8962 ' = 1  /* AMPUTATION FOOT, BILAT */
'8963 ' = 1  /* AMPUTAT FOOT, BILAT-COMP */
'8970 ' = 1  /* AMPUT BELOW KNEE, UNILAT */
'8971 ' = 1  /* AMPUTAT BK, UNILAT-COMPL */
'8972 ' = 1  /* AMPUT ABOVE KNEE, UNILAT */
'8973 ' = 1  /* AMPUT ABV KN, UNIL-COMPL */
'8974 ' = 1  /* AMPUTAT LEG, UNILAT NOS */
'8975 ' = 1  /* AMPUT LEG, UNIL NOS-COMP */
'8976 ' = 1  /* AMPUTATION LEG, BILAT */
'8977 ' = 1  /* AMPUTAT LEG, BILAT-COMPL */
other   = 0;
/* EXCLUDE: TOE AMPUTATION PROCEDURE   */
/* ICD-9-CM DIAGNOSIS CODES:  */
value $TOEAMIP
'8411' = 1   /* TOE AMPUTAION  */  
other   = 0;
* -----------------------------------------------------;
* --- DRG FORMATS  ------------------------------------;
* -----------------------------------------------------;

/* MS-DRG (V25) TO MDC */
value MDCF2T_PQI
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
other  = 99;
* -----------------------------------------------------;
* --- AREA FORMATS ------------------------------------;
* ---   Translates FIPS State and County Code (SSCCC)
* ---   to MSA (Metropolitan Statistical Area)
* -----------------------------------------------------;
/* MODIFIED FIPS */
value $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069';
/* OMB 1999 METRO AREA */
value $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 ';
/* OMB 2003 METRO AREA */
value $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740';
/* -------------------------------------------------------------- */
/* --- FORMATS FOR AGE STRATIFIERS                            --- */
/* -------------------------------------------------------------- */
Value AGEFMT
low - 4 =  1
5 -  9 =  2
10 - 14 =  3
15 - 17 =  4
18 - 24 =  5
25 - 29 =  6
30 - 34 =  7
35 - 39 =  8
40 - 44 =  9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;
RUN;
